@@ -1,5 +1,5 @@
 """
-Phypno main module
+Wonambi main module
 """
 from os import path
 
@@ -13,4 +13,4 @@ from .graphoelement import Graphoelement
 try:
     from .bin.scroll_data import MainWindow as Wonambi
 except ImportError:  # PyQt is not installed
-    Wonambi = None
+    Wonambi = None
\ No newline at end of file
