@@ -3,7 +3,7 @@
 """
 from logging import getLogger
 from numpy import (argmin, concatenate, diff, hstack, logical_and, newaxis, 
-                   sign, sum, vstack, where, zeros)
+                   ones, percentile, sign, sum, vstack, where, zeros)
 
 try:
     from PyQt5.QtCore import Qt
@@ -62,6 +62,15 @@ class DetectSlowWave:
             self.peak_thresh = 1.25
             self.ptp_thresh = 1.25
             self.invert = False
+            
+        elif method == 'Staresina2015':
+            self.lowpass = {'order': 3, 
+                            'freq': 1.25}
+            self.min_dur = 0.8
+            self.max_dur = 2.0
+            self.det_filt = {'freq': (1 / self.max_dur, 1 / self.min_dur)}
+            self.ptp_thresh = 75
+            self.invert = False
 
         else:
             raise ValueError('Unknown method')
@@ -105,6 +114,7 @@ class DetectSlowWave:
             lg.info('Detecting slow waves on chan %s', chan)
             time = hstack(data.axis['time'])
             dat_orig = hstack(data(chan=chan))
+            dat_orig = dat_orig - dat_orig.mean()  # demean
 
             if 'Massimini2004' in self.method:
                 sw_in_chan = detect_Massimini2004(dat_orig, data.s_freq, time,
@@ -112,6 +122,10 @@ class DetectSlowWave:
                 
             elif 'Ngo2015' == self.method:
                 sw_in_chan = detect_Ngo2015(dat_orig, data.s_freq, time, self)
+                
+            elif 'Staresina2015' == self.method:
+                sw_in_chan = detect_Staresina2015(dat_orig, data.s_freq, time, 
+                                                  self)
 
             else:
                 raise ValueError('Unknown method')
@@ -210,21 +224,17 @@ def detect_Ngo2015(dat_orig, s_freq, time, opts):
     time : ndarray (dtype='float')
         vector with the time points for each sample
     opts : instance of 'DetectSlowWave'
-        'det_filt' : dict
-            parameters for 'butter',
+        'lowpass' : dict
+            parameters for 'low_butter',
         'duration' : tuple of float
             min and max duration of SW
         'min_ptp' : float
             min peak-to-peak amplitude
-        'trough_duration' : tuple of float
-            min and max duration of first half-wave (trough)
 
     Returns
     -------
     list of dict
         list of detected SWs
-    float
-        SW density, per 30-s epoch
 
     References
     ----------
@@ -235,39 +245,89 @@ def detect_Ngo2015(dat_orig, s_freq, time, opts):
         dat_orig = -dat_orig
 
     sw_in_chan = []
-    dat_det = transform_signal(dat_orig, s_freq, 'low_butter', opts.lowpass)
-    idx_zx = find_zero_crossings(dat_det, xtype='pos_to_neg')
-    print(len(idx_zx))
-    events = find_intervals(idx_zx, s_freq, opts.duration)
-    print(events.shape)
+    dat_det = transform_signal(dat_orig, s_freq, 'low_butter', opts.lowpass) #filter to SO range
+    idx_zx = find_zero_crossings(dat_det, xtype='pos_to_neg') #detect crossing from pos to neg (visual down to up)
+    events = find_intervals(idx_zx, s_freq, opts.duration) #event within duration set up
     if events is not None:
-        events = find_peaks_in_slowwwave(dat_det, events)
-        print(events.shape)
-        
-        # Negative peak threshold
-        neg_peak = events[:, 1]
-        neg_peak_thresh = neg_peak.mean() * opts.peak_thresh
-        events = events[neg_peak < neg_peak_thresh, :]
-        print(events.shape)
-        
-        # Peak-to-peak amplitude threshold
-        ptp = events[:, 3] - events[:, 1]
-        ptp_thresh = ptp.mean() * opts.ptp_thresh
-        events = events[ptp > ptp_thresh, :]
-        print(events.shape)
+        events = find_peaks_in_slowwwave(dat_det, events) #finds start, trough, crossing, peak, end of sw
         
         if events is not None:
-            events = within_duration(events, time, opts.duration)
-            print(events.shape)
-            events = remove_straddlers(events, time, s_freq)
-            print(events.shape)
-            sw_in_chan = make_slow_waves(events, dat_det, time, s_freq)
+            # Negative peak threshold
+            idx_neg_peak = events[:, 1] #finds index(sample) of trough of sw (but try with [:,3])
+            neg_peak_thresh = dat_det[idx_neg_peak].mean() * opts.peak_thresh #multiples mean of all trough by threshold
+            events = events[dat_det[idx_neg_peak] < neg_peak_thresh, :] 
+            
+            if events is not None:
+                # Peak-to-peak amplitude threshold
+                ptp = dat_det[events[:, 3]] - dat_det[events[:, 1]] # for each event, subtract trough from peak
+                ptp_thresh = ptp.mean() * opts.ptp_thresh # np.percentile(ptp, 75)
+                events = events[ptp > ptp_thresh, :] # filter events above peak to peak threshold
+                
+                if events is not None:
+                    #events = within_duration(events, time, opts.duration)
+                    events = remove_straddlers(events, time, s_freq)
+                    sw_in_chan = make_slow_waves(events, dat_det, time, s_freq)
         
     if sw_in_chan:
         lg.info('No slow waves found')
 
     return sw_in_chan
 
+def detect_Staresina2015(dat_orig, s_freq, time, opts):
+    """Slow wave detection based on Ngo et al., 2015.
+
+    Parameters
+    ----------
+    dat_orig : ndarray (dtype='float')
+        vector with the data for one channel
+    s_freq : float
+        sampling frequency
+    time : ndarray (dtype='float')
+        vector with the time points for each sample
+    opts : instance of 'DetectSlowWave'
+        'det_remez' : dict
+            parameters for 'remez' (FIR filter),
+        'duration' : tuple of float
+            min and max duration of SW
+        'min_ptp' : float
+            min peak-to-peak amplitude
+
+    Returns
+    -------
+    list of dict
+        list of detected SWs
+
+    References
+    ----------
+    Staresina, B. et al. 18(11) 1679-86 (2015).
+
+    """
+    if opts.invert:
+        dat_orig = -dat_orig
+
+    sw_in_chan = []
+    dat_det = transform_signal(dat_orig, s_freq, 'low_butter', opts.lowpass) #filter to SO range
+    idx_zx = find_zero_crossings(dat_det, xtype='pos_to_neg') #detect crossing from pos to neg (visual down to up)
+    events = find_intervals(idx_zx, s_freq, opts.duration) #event within duration set up
+
+    if events is not None:
+        events = find_peaks_in_slowwwave(dat_det, events) #finds start, trough, crossing, peak, end of sw
+
+        if events is not None:
+            # Peak-to-peak amplitude threshold
+            ptp = dat_det[events[:, 3]] - dat_det[events[:, 1]] # for each event, subtract trough from peak
+            ptp_thresh = percentile(ptp, opts.ptp_thresh)
+            events = events[ptp >= ptp_thresh, :] # filter events above peak to peak threshold
+            
+            if events is not None:
+                #events = within_duration(events, time, opts.duration)
+                events = remove_straddlers(events, time, s_freq)
+                sw_in_chan = make_slow_waves(events, dat_det, time, s_freq)
+        
+    if sw_in_chan:
+        lg.info('No slow waves found')
+
+    return sw_in_chan
 
 def select_peaks(data, events, limit):
     """Check whether event satisfies amplitude limit.
@@ -479,10 +539,15 @@ def find_peaks_in_slowwwave(data, events):
         events[:, 1, newaxis]), 
                         axis=1)
     
+    selected = ones(events.shape[0], dtype='bool')
     for i, ev in enumerate(events):
-        ev_dat = data[ev[0]:ev[1]]
-        new_events[i, 1] = ev[0] + ev_dat.argmin() # trough
-        new_events[i, 2] = ev[0] + where(diff(sign(ev_dat)) > 0)[0][0] # -to+
-        new_events[i, 3] = ev[0] + ev_dat.argmax() # peak
+        try:
+            ev_dat = data[ev[0]:ev[1]]
+            new_events[i, 1] = ev[0] + ev_dat.argmin() # trough
+            new_events[i, 2] = ev[0] + where(diff(sign(ev_dat)) > 0)[0][0] # -to+
+            new_events[i, 3] = ev[0] + ev_dat.argmax() # peak
+        except IndexError:
+            selected[i] = False
         
-    return new_events
\ No newline at end of file
+    return new_events[selected, :]
+
