@@ -104,8 +104,8 @@ class ConfigTraces(Config):
         form_layout.addRow('Lines at + and - (uV):', self.index['grid_ytick'])
 
         box2 = QGroupBox('Current Window')
-        self.index['window_start'] = FormInt()
-        self.index['window_length'] = FormInt()
+        self.index['window_start'] = FormFloat()
+        self.index['window_length'] = FormFloat()
         self.index['window_step'] = FormInt()
 
         form_layout = QFormLayout()
@@ -339,6 +339,8 @@ class Traces(QGraphicsView):
 
         if not chan_to_read:
             return
+
+        lg.debug(f'Reading data from dataset: begtime={window_start:10.3f}, endtime={window_end:10.3f}, {len(chan_to_read)} channels')
         data = dataset.read_data(chan=chan_to_read,
                                  begtime=window_start,
                                  endtime=window_end)
@@ -560,7 +562,7 @@ class Traces(QGraphicsView):
                 self.scene.addItem(item)
 
                 item = TextItem_with_BG(color.darker(200))
-                item.setText(mrk['name'])
+                item.setText(str(mrk['name']))
                 item.setPos(mrk['start'],
                             len(self.idx_label) *
                             self.parent.value('y_distance'))
@@ -722,17 +724,21 @@ class Traces(QGraphicsView):
         self.parent.overview.update_position(window_start)
 
     def X_more(self):
-        """Zoom in on the x-axis."""
-        if self.parent.value('window_length') < 0.3:
-            return
-        self.parent.value('window_length',
-                          self.parent.value('window_length') * 2)
+        """Zoom out on the x-axis."""
+        new_length = self.parent.value('window_length') * 2
+        self.parent.value('window_length', new_length)
+        new_start = self.parent.value('window_start') - new_length / 4
+        self.parent.value('window_start', new_start)
+
         self.parent.overview.update_position()
 
     def X_less(self):
-        """Zoom out on the x-axis."""
-        self.parent.value('window_length',
-                          self.parent.value('window_length') / 2)
+        """Zoom in on the x-axis."""
+        new_length = self.parent.value('window_length') / 2
+        self.parent.value('window_length', new_length)
+        new_start = self.parent.value('window_start') + new_length / 2
+        self.parent.value('window_start', new_start)
+
         self.parent.overview.update_position()
 
     def X_length(self, new_window_length):
